@@ -1,6 +1,6 @@
 use {
-    clap::{value_t, value_t_or_exit, App, Arg},
-    fd_lock::FdLock,
+    clap::{crate_name, value_t, value_t_or_exit, App, Arg},
+    log::*,
     solana_clap_utils::{
         input_parsers::{pubkey_of, pubkeys_of, value_of},
         input_validators::{
@@ -24,8 +24,8 @@ use {
     },
     solana_streamer::socket::SocketAddrSpace,
     solana_validator::{
-        admin_rpc_service, dashboard::Dashboard, println_name_value, redirect_stderr_to_file,
-        test_validator::*,
+        admin_rpc_service, dashboard::Dashboard, ledger_lockfile, lock_ledger, println_name_value,
+        redirect_stderr_to_file, test_validator::*,
     },
     std::{
         collections::HashSet,
@@ -168,7 +168,7 @@ fn main() {
             Arg::with_name("no_bpf_jit")
                 .long("no-bpf-jit")
                 .takes_value(false)
-                .help("Disable the just-in-time compiler and instead use the interpreter for BPF"),
+                .help("Disable the just-in-time compiler and instead use the interpreter for BPF. Windows always disables JIT."),
         )
         .arg(
             Arg::with_name("slots_per_epoch")
@@ -304,15 +304,8 @@ fn main() {
         });
     }
 
-    let mut ledger_fd_lock = FdLock::new(fs::File::open(&ledger_path).unwrap());
-    let _ledger_lock = ledger_fd_lock.try_lock().unwrap_or_else(|_| {
-        println!(
-            "Error: Unable to lock {} directory. Check if another validator is running",
-            ledger_path.display()
-        );
-        exit(1);
-    });
-
+    let mut ledger_lock = ledger_lockfile(&ledger_path);
+    let _ledger_write_guard = lock_ledger(&ledger_path, &mut ledger_lock);
     if reset_ledger {
         remove_directory_contents(&ledger_path).unwrap_or_else(|err| {
             println!("Error: Unable to remove {}: {}", ledger_path.display(), err);
@@ -322,6 +315,7 @@ fn main() {
     solana_runtime::snapshot_utils::remove_tmp_snapshot_archives(&ledger_path);
 
     let validator_log_symlink = ledger_path.join("validator.log");
+
     let logfile = if output != Output::Log {
         let validator_log_with_timestamp = format!(
             "validator-{}.log",
@@ -346,6 +340,8 @@ fn main() {
     };
     let _logger_thread = redirect_stderr_to_file(logfile);
 
+    info!("{} {}", crate_name!(), solana_version::version!());
+    info!("Starting validator with: {:#?}", std::env::args_os());
     solana_core::validator::report_target_features();
 
     // TODO: Ideally test-validator should *only* allow private addresses.
@@ -395,6 +391,10 @@ fn main() {
         IpAddr::V4(Ipv4Addr::new(0, 0, 0, 0)),
         faucet_port,
     ));
+    // JIT not supported on the BPF VM in Windows currently: https://github.com/solana-labs/rbpf/issues/217
+    #[cfg(target_family = "windows")]
+    let bpf_jit = false;
+    #[cfg(not(target_family = "windows"))]
     let bpf_jit = !matches.is_present("no_bpf_jit");
 
     let mut programs = vec![];
